/**
 * Copyright (c) 2016-2018 Thales Global Services S.A.S.
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 *   Abel Hegedus, Tamas Borbas, Peter Lunk, Daniel Segesdi (IncQuery Labs Ltd.) - initial API and implementation
 */
package org.eclipse.emf.diffmerge.patch.api.filters;

import com.google.common.base.Objects;
import com.google.common.base.Preconditions;
import java.util.List;
import org.eclipse.emf.diffmerge.patch.api.ComplexMPEFilterType;
import org.eclipse.emf.diffmerge.patch.api.IModelPatchEntryFilter;
import org.eclipse.emf.diffmerge.patch.api.ModelPatchEntry;
import org.eclipse.xtend.lib.annotations.AccessorType;
import org.eclipse.xtend.lib.annotations.Accessors;
import org.eclipse.xtext.xbase.lib.Conversions;
import org.eclipse.xtext.xbase.lib.Functions.Function1;
import org.eclipse.xtext.xbase.lib.IterableExtensions;
import org.eclipse.xtext.xbase.lib.Pure;

@SuppressWarnings("all")
public class ComplexEntryFilter implements IModelPatchEntryFilter {
  @Accessors(AccessorType.PUBLIC_GETTER)
  private ComplexMPEFilterType type;
  
  @Accessors(AccessorType.PUBLIC_GETTER)
  private List<IModelPatchEntryFilter> subFilters;
  
  public ComplexEntryFilter(final ComplexMPEFilterType type, final IModelPatchEntryFilter... subFilters) {
    Preconditions.<ComplexMPEFilterType>checkNotNull(type);
    Preconditions.<IModelPatchEntryFilter[]>checkNotNull(subFilters);
    this.type = type;
    this.subFilters = ((List<IModelPatchEntryFilter>)Conversions.doWrapArray(subFilters));
  }
  
  @Override
  public boolean isEntryFiltered(final ModelPatchEntry entry) {
    boolean _equals = Objects.equal(this.type, ComplexMPEFilterType.OR);
    if (_equals) {
      final Function1<IModelPatchEntryFilter, Boolean> _function = (IModelPatchEntryFilter it) -> {
        return Boolean.valueOf(it.isEntryFiltered(entry));
      };
      return IterableExtensions.<IModelPatchEntryFilter>exists(this.subFilters, _function);
    } else {
      final Function1<IModelPatchEntryFilter, Boolean> _function_1 = (IModelPatchEntryFilter it) -> {
        return Boolean.valueOf(it.isEntryFiltered(entry));
      };
      return IterableExtensions.<IModelPatchEntryFilter>forall(this.subFilters, _function_1);
    }
  }
  
  @Pure
  public ComplexMPEFilterType getType() {
    return this.type;
  }
  
  @Pure
  public List<IModelPatchEntryFilter> getSubFilters() {
    return this.subFilters;
  }
}
