/**
 * Copyright (c) 2016-2018 Thales Global Services S.A.S.
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 *   Abel Hegedus, Tamas Borbas, Balazs Grill, Peter Lunk, Daniel Segesdi (IncQuery Labs Ltd.) - initial API and implementation
 */
package org.eclipse.emf.diffmerge.patch.runtime;

import org.eclipse.emf.ecore.EObject;
import org.eclipse.emf.ecore.EStructuralFeature;
import org.eclipse.xtend.lib.annotations.Data;
import org.eclipse.xtext.xbase.lib.Pure;
import org.eclipse.xtext.xbase.lib.util.ToStringBuilder;

@Data
@SuppressWarnings("all")
public class FeatureHolder {
  private final EObject eObject;
  
  private final EStructuralFeature feature;
  
  public FeatureHolder(final EObject eObject, final EStructuralFeature feature) {
    super();
    this.eObject = eObject;
    this.feature = feature;
  }
  
  @Override
  @Pure
  public int hashCode() {
    final int prime = 31;
    int result = 1;
    result = prime * result + ((this.eObject== null) ? 0 : this.eObject.hashCode());
    return prime * result + ((this.feature== null) ? 0 : this.feature.hashCode());
  }
  
  @Override
  @Pure
  public boolean equals(final Object obj) {
    if (this == obj)
      return true;
    if (obj == null)
      return false;
    if (getClass() != obj.getClass())
      return false;
    FeatureHolder other = (FeatureHolder) obj;
    if (this.eObject == null) {
      if (other.eObject != null)
        return false;
    } else if (!this.eObject.equals(other.eObject))
      return false;
    if (this.feature == null) {
      if (other.feature != null)
        return false;
    } else if (!this.feature.equals(other.feature))
      return false;
    return true;
  }
  
  @Override
  @Pure
  public String toString() {
    ToStringBuilder b = new ToStringBuilder(this);
    b.add("eObject", this.eObject);
    b.add("feature", this.feature);
    return b.toString();
  }
  
  @Pure
  public EObject getEObject() {
    return this.eObject;
  }
  
  @Pure
  public EStructuralFeature getFeature() {
    return this.feature;
  }
}
